@@ -27,37 +27,27 @@ testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
 
 @pytest.mark.parametrize(
     'path',
-    ['fluentd/filter',
-     'fluentd/input',
-     'fluentd/output'])
-def test_service_config_directory(host, path):
-    path = os.path.join('/etc/kolla/config', path)
-    utils.test_directory(host, path)
-
-
-@pytest.mark.parametrize(
-    'path',
-    ['ceph',
+    ['aodh',
      'cinder',
+     'cloudkitty',
      'designate',
+     'fluentd/filter',
+     'fluentd/input',
+     'fluentd/output',
      'glance',
      'grafana',
      'heat',
      'horizon',
      'ironic',
-     'kafka',
      'keystone',
      'magnum',
      'manila',
      'mariadb',
-     'monasca',
-     'murano',
+     'masakari',
      'neutron',
      'nova',
-     'sahara',
-     'storm',
-     'swift',
-     'zookeeper'])
+     'prometheus',
+     'swift'])
 def test_service_config_directory_absent(host, path):
     path = os.path.join('/etc/kolla/config', path)
     utils.test_path_absent(host, path)
